pub trait HomogeneousTuple<Item>: Tuple {
type Array: Array<Item = Item>;
// Required methods
fn into_array(self) -> Self::Array
where Self: Sized;
fn from_array(array: Self::Array) -> Self;
}Required Associated Types
Required Methods
fn into_array(self) -> Self::Arraywhere
Self: Sized,
fn from_array(array: Self::Array) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T> HomogeneousTuple<T> for ()
impl<T> HomogeneousTuple<T> for ()
Sourceimpl<T> HomogeneousTuple<T> for (T₁, T₂, …, Tₙ)
This trait is implemented for tuples up to 12 items long.
impl<T> HomogeneousTuple<T> for (T₁, T₂, …, Tₙ)
This trait is implemented for tuples up to 12 items long.