pub trait Tuple: Primitive {
const N: usize;
}Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T1: ?Sized> Tuple for (T1₁, T1₂, …, T1ₙ)
This trait is implemented for tuples up to 12 items long.
impl<T1: ?Sized> Tuple for (T1₁, T1₂, …, T1ₙ)
This trait is implemented for tuples up to 12 items long.